nxp-pac

Crates

git

Versions

lpc55s16

Flavors

DummyCtrl

Struct DummyCtrl 

#[repr(transparent)]
pub struct DummyCtrl(pub u32);
Dummy Control bus to analog modules

Tuple Fields

0: u32

Implementations

Source

impl DummyCtrl

pub const fn xo32m_adc_clk_mode(&self) -> Xo32mAdcClkMode

Control High speed Crystal oscillator mode of the ADC clock.

pub const fn set_xo32m_adc_clk_mode(&mut self, val: Xo32mAdcClkMode)

Control High speed Crystal oscillator mode of the ADC clock.